# System Models

Classes for representing Grocy server information, time, and configuration.

## SystemInfo

::: grocy.data_models.system.SystemInfo
    options:
      members_order: source

## SystemTime

::: grocy.data_models.system.SystemTime
    options:
      members_order: source

## SystemConfig

::: grocy.data_models.system.SystemConfig
    options:
      members_order: source
